pm4py.algo.reduction.process\_tree.variants package
===================================================

Submodules
----------

pm4py.algo.reduction.process\_tree.variants.tree\_tr\_based module
------------------------------------------------------------------

.. automodule:: pm4py.algo.reduction.process_tree.variants.tree_tr_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.reduction.process_tree.variants
   :members:
   :undoc-members:
   :show-inheritance:
